--|> EVENT HANDLER
-------------------------------------------------------------------------------
local _, NS = ...

--> Upvalues
--------------------
local UnitIsUnit = UnitIsUnit
local UnitExists = UnitExists

--> EVENT FRAME
--------------------
local EventFrame = CreateFrame("Frame", nil, UIParent)
EventFrame:Hide()
EventFrame:RegisterEvent("PLAYER_ENTERING_WORLD")

--> EVENTS: OnEvent
--: Send to event function, if exists
EventFrame:SetScript(
    "OnEvent",
    function(self, event, ...)
        return self[event] and self[event](self, ...)
    end
)

--|> EVENTS
-------------------------------------------------------------------------------
---
--> @E PLAYER_ENTERING_WORLD
--: Takes place post-loading screen, zoning, porting, reloading ui, etc
-----------------------------
function EventFrame.PLAYER_ENTERING_WORLD()
    NS.EnteringWorld()
end

--> @E NAME_PLATE_UNIT_ADDED
-----------------------------
function EventFrame.NAME_PLATE_UNIT_ADDED(_, unit)
    if UnitIsUnit(unit, "focus") then
        FTL_FOCUS_FRAME:Show()
    elseif UnitIsUnit(unit, "focustarget") then
        FTL_FOCUS_TARGET_FRAME:Show()
    end
end

--> @E NAME_PLATE_UNIT_REMOVED
-----------------------------
function EventFrame.NAME_PLATE_UNIT_REMOVED(_, unit)
    if UnitIsUnit(unit, "focus") then
        FTL_FOCUS_FRAME:Hide()
    elseif UnitIsUnit(unit, "focustarget") then
        FTL_FOCUS_TARGET_FRAME:Hide()
    end
end

--> @E PLAYER_FOCUS_CHANGED
-----------------------------
function EventFrame.PLAYER_FOCUS_CHANGED()
    if not UnitExists("focus") then
        FTL_FOCUS_FRAME:Hide()
        FTL_FOCUS_TARGET_FRAME:Hide()
    else
        FTL_FOCUS_FRAME:Show()
        FTL_FOCUS_TARGET_FRAME:Show()
    end
end

--> @E PLAYER_TARGET_CHANGED
-----------------------------
function EventFrame.PLAYER_TARGET_CHANGED()
    if UnitIsUnit("focustarget", "focus") then
        FTL_FOCUS_TARGET_FRAME:Hide()
    else
        FTL_FOCUS_TARGET_FRAME:CheckForAssist()
    end
end

--> @E UNIT_TARGET
-----------------------------
function EventFrame.UNIT_TARGET(_, unit)
    if unit == "focus" then
        if UnitIsUnit("focustarget", "focus") then
            FTL_FOCUS_TARGET_FRAME:Hide()
        else
            FTL_FOCUS_TARGET_FRAME:CheckForAssist()
        end
    end
end

--|> FUNCTIONS
-------------------------------------------------------------------------------

--> Enable Event Listening
-----------------------------
function NS.EnableEvents()
    EventFrame:RegisterEvent("NAME_PLATE_UNIT_ADDED")
    EventFrame:RegisterEvent("NAME_PLATE_UNIT_REMOVED")
    EventFrame:RegisterEvent("PLAYER_FOCUS_CHANGED")
    EventFrame:RegisterEvent("PLAYER_TARGET_CHANGED")
    EventFrame:RegisterEvent("UNIT_TARGET")
end

--> Disable Event Listening
-----------------------------
function NS.DisableEvents()
    EventFrame:UnregisterEvent("NAME_PLATE_UNIT_ADDED")
    EventFrame:UnregisterEvent("NAME_PLATE_UNIT_REMOVED")
    EventFrame:UnregisterEvent("PLAYER_FOCUS_CHANGED")
    EventFrame:UnregisterEvent("PLAYER_TARGET_CHANGED")
    EventFrame:UnregisterEvent("UNIT_TARGET")
end
