--|> LDB
-----------------------------------------------------------
local ADDON_NAME, NS = ...

local addonTitle = "|cff3ef7b1FTL|r"
local disabledString = "|cfff40068Disabled|r"
local enabledString = "|cff4cf452Enabled|r"

local ldb = LibStub:GetLibrary("LibDataBroker-1.1", true)
if not ldb then
    NS.PrintAddonMessage("LibDataBroker-1.1 not found!")
    return
end

--> Create LDB plugin
----------------------------------------
NS.MiniMapIcon =
    ldb:NewDataObject(
    ADDON_NAME,
    {
        type = "data source",
        text = "0",
        icon = "Interface/Addons/FTL/Media/Icons/minimap.tga"
    }
)

function NS.MiniMapIcon.BuildToolTip()
    if FTL_CHARACTER_OPTIONS.Enabled == true then
        LibDBIconTooltip:AddDoubleLine(addonTitle, enabledString)
        LibDBIconTooltip:AddLine("Right-Click to disable")
    else
        LibDBIconTooltip:AddDoubleLine(addonTitle, disabledString)
        LibDBIconTooltip:AddLine("Right-Click to enable")
    end
end

--> OnClick
----------------------------------------
function NS.MiniMapIcon.OnClick(_, button)
    if button == "RightButton" then
        if FTL_CHARACTER_OPTIONS.Enabled == true then
            NS.Disable()
            NS.PrintAddonMessage(disabledString)
            FTL_CHARACTER_OPTIONS.Enabled = false
        else
            NS.Enable()
            NS.PrintAddonMessage(enabledString)
            FTL_CHARACTER_OPTIONS.Enabled = true
        end
        LibDBIconTooltip:ClearLines()
        NS.MiniMapIcon.BuildToolTip()
    end
end

--> OnTooltipShow
----------------------------------------
function NS.MiniMapIcon.OnTooltipShow()
    NS.MiniMapIcon.BuildToolTip()
end

--> Enable on Login
----------------------------------------
local f = CreateFrame("Frame")
f:SetScript(
    "OnEvent",
    function()
        NS.LibDBIcon = NS.LibDBIcon or LibStub("LibDBIcon-1.0", true)
        if not NS.LibDBIcon then
            return
        end
        NS.LibDBIcon:Register(ADDON_NAME, NS.MiniMapIcon, FTL_CHARACTER_OPTIONS.LDB)
        LibStub("LibDBIcon-1.0"):Show(ADDON_NAME)
        f:UnregisterEvent("PLAYER_LOGIN")
    end
)
f:RegisterEvent("PLAYER_LOGIN")
